==> parcel-bundler-vue-1.6.3.tgz: package/lib/Parser.js <==
'use strict';

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var path = require('path');
var RawAsset = require('./assets/RawAsset');
var GlobAsset = require('./assets/GlobAsset');
var glob = require('glob');

var Parser = function () {
  function Parser() {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    (0, _classCallCheck3.default)(this, Parser);

    this.extensions = {};

    this.registerExtension('js', './assets/JSAsset');
    this.registerExtension('jsx', './assets/JSAsset');
    this.registerExtension('es6', './assets/JSAsset');
    this.registerExtension('jsm', './assets/JSAsset');
    this.registerExtension('mjs', './assets/JSAsset');
    this.registerExtension('ml', './assets/ReasonAsset');
    this.registerExtension('re', './assets/ReasonAsset');
    this.registerExtension('ts', './assets/TypeScriptAsset');
    this.registerExtension('tsx', './assets/TypeScriptAsset');
    this.registerExtension('coffee', './assets/CoffeeScriptAsset');
    this.registerExtension('json', './assets/JSONAsset');
    this.registerExtension('json5', './assets/JSONAsset');
    this.registerExtension('yaml', './assets/YAMLAsset');
    this.registerExtension('yml', './assets/YAMLAsset');
    this.registerExtension('toml', './assets/TOMLAsset');
    this.registerExtension('gql', './assets/GraphqlAsset');
    this.registerExtension('graphql', './assets/GraphqlAsset');
    this.registerExtension('vue', './assets/VueAsset');

    this.registerExtension('css', './assets/CSSAsset');
    this.registerExtension('pcss', './assets/CSSAsset');
    this.registerExtension('styl', './assets/StylusAsset');
    this.registerExtension('stylus', './assets/StylusAsset');
    this.registerExtension('less', './assets/LESSAsset');
    this.registerExtension('sass', './assets/SASSAsset');
    this.registerExtension('scss', './assets/SASSAsset');

    this.registerExtension('html', './assets/HTMLAsset');
    this.registerExtension('htm', './assets/HTMLAsset');
    this.registerExtension('rs', './assets/RustAsset');

    this.registerExtension('webmanifest', './assets/WebManifestAsset');

    var extensions = options.extensions || {};
    for (var ext in extensions) {
      this.registerExtension(ext, extensions[ext]);
    }
  }

  (0, _createClass3.default)(Parser, [{
    key: 'registerExtension',
    value: function registerExtension(ext, parser) {
      if (!ext.startsWith('.')) {
        ext = '.' + ext;
      }

      this.extensions[ext.toLowerCase()] = parser;
    }
  }, {
    key: 'findParser',
    value: function findParser(filename) {
      if (glob.hasMagic(filename)) {
        return GlobAsset;
      }

      var extension = path.extname(filename).toLowerCase();
      var parser = this.extensions[extension] || RawAsset;
      if (typeof parser === 'string') {
        parser = this.extensions[extension] = require(parser);
      }

      return parser;
    }
  }, {
    key: 'getAsset',
    value: function getAsset(filename, pkg) {
      var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      var contents = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;

      if (contents != null) {
        options = (0, _assign2.default)({}, options, { contents: contents });
      }
      var Asset = this.findParser(filename);
      options.parser = this;
      return new Asset(filename, pkg, options);
    }
  }]);
  return Parser;
}();

module.exports = Parser;

==> parcel-bundler-vue-2.0.0.tgz: package/lib/Parser.js <==
'use strict';

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var path = require('path');
var RawAsset = require('./assets/RawAsset');
var GlobAsset = require('./assets/GlobAsset');
var glob = require('glob');

var Parser = function () {
  function Parser() {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    (0, _classCallCheck3.default)(this, Parser);

    this.extensions = {};

    this.registerExtension('js', './assets/JSAsset');
    this.registerExtension('jsx', './assets/JSAsset');
    this.registerExtension('es6', './assets/JSAsset');
    this.registerExtension('jsm', './assets/JSAsset');
    this.registerExtension('mjs', './assets/JSAsset');
    this.registerExtension('ml', './assets/ReasonAsset');
    this.registerExtension('re', './assets/ReasonAsset');
    this.registerExtension('ts', './assets/TypeScriptAsset');
    this.registerExtension('tsx', './assets/TypeScriptAsset');
    this.registerExtension('coffee', './assets/CoffeeScriptAsset');
    this.registerExtension('json', './assets/JSONAsset');
    this.registerExtension('yaml', './assets/YAMLAsset');
    this.registerExtension('yml', './assets/YAMLAsset');
    this.registerExtension('gql', './assets/GraphqlAsset');
    this.registerExtension('graphql', './assets/GraphqlAsset');
    this.registerExtension('vue', './assets/VueAsset');

    this.registerExtension('css', './assets/CSSAsset');
    this.registerExtension('pcss', './assets/CSSAsset');
    this.registerExtension('styl', './assets/StylusAsset');
    this.registerExtension('stylus', './assets/StylusAsset');
    this.registerExtension('less', './assets/LESSAsset');
    this.registerExtension('sass', './assets/SASSAsset');
    this.registerExtension('scss', './assets/SASSAsset');

    this.registerExtension('html', './assets/HTMLAsset');

    var extensions = options.extensions || {};
    for (var ext in extensions) {
      this.registerExtension(ext, extensions[ext]);
    }
  }

  (0, _createClass3.default)(Parser, [{
    key: 'registerExtension',
    value: function registerExtension(ext, parser) {
      if (!ext.startsWith('.')) {
        ext = '.' + ext;
      }

      this.extensions[ext] = parser;
    }
  }, {
    key: 'findParser',
    value: function findParser(filename) {
      if (glob.hasMagic(filename)) {
        return GlobAsset;
      }

      var extension = path.extname(filename);
      var parser = this.extensions[extension] || RawAsset;
      if (typeof parser === 'string') {
        parser = this.extensions[extension] = require(parser);
      }

      return parser;
    }
  }, {
    key: 'getAsset',
    value: function getAsset(filename, pkg) {
      var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      var contents = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;

      if (contents != null) {
        options = (0, _assign2.default)({}, options, { contents: contents });
      }
      var Asset = this.findParser(filename);
      options.parser = this;
      return new Asset(filename, pkg, options);
    }
  }]);
  return Parser;
}();

module.exports = Parser;
